local addonName, vars = ...
local L = vars.L
SkinSound = vars
local addon = SkinSound
local settings

local debugEnabled = false -- for addon debugging

local defaults = {
  enabled = true,
  playfrequency = 5,
  sound = true,
  yell = true,
}

local function chatMsg(msg) 
     DEFAULT_CHAT_FRAME:AddMessage(addonName..": "..msg)
end
local function debug(msg) 
  if debugEnabled then
     chatMsg(msg)
  end
end

local soundfiles = {
  rub1     = { p=10, t=3 },
  rub2     = { p=10, t=4 },
  basket   = { p=5,  t=2 },
  cartman1 = { p=10, t=6 },
  dirt1    = { p=10, t=6 },
  dirt2    = { p=10, t=6 },
  green1   = { p=5,  t=16 },
  stewie1  = { p=10, t=4 },
}
addon.soundtable = {}
addon.soundsum = 0
for name, data in pairs(soundfiles) do
  table.insert(addon.soundtable, { 
       "Interface\\AddOns\\"..addonName.."\\sound\\"..name..".ogg", data.p, data.t
    })
  addon.soundsum = addon.soundsum + data.p
end

function addon:doSkin()
  if not settings or not settings.enabled then return end
  local now = GetTime()
  local pause = settings.playfrequency
  if now < (addon.nextplay or 0) then
    return
  end
  if settings.sound then
    local roll = math.random(addon.soundsum)
    for _,e in ipairs(addon.soundtable) do
      local f,p,t = unpack(e)
      roll = roll - p
      if roll <= 0 then
        PlaySoundFile(f, "Master")
	pause = math.max(pause, t)
        break
      end
    end
  end
  if settings.yell then
    local msg = settings.msg or "It rubs the lotion on its skin!"
    SendChatMessage(msg,"YELL")
  end
  addon.nextplay = now + pause
end

local skinning = GetSpellInfo(74522)
local itemstr = LOOT_ITEM_PUSHED_SELF:gsub("%%s","%(.*%)")
local cageitems = {
  [119813] = true, 	-- Furry Caged Beast
  [119810] = true, 	-- Meaty Caged Beast
  [119814] = true, 	-- Leathery Caged Beast
  [119815] = true, 	-- Caged Mighty Wolf
  [119817] = true, 	-- Caged Mighty Riverbeast
  [119819] = true, 	-- Caged Mighty Clefthoof
}

local function frame_OnEvent(self,event,...)
 if event == "ADDON_LOADED" and select(1,...) == addonName then  
   if not SkinSoundSettings then
     SkinSoundSettings = {} 
   end
   settings = SkinSoundSettings
   for k,v in pairs(defaults) do
     if settings[k] == nil then
        settings[k] = v
     end
   end
 elseif event == "UNIT_SPELLCAST_START" then
   local unitID, spell, rank, lineID, spellID = ...
   if unitID == "player" and spell == skinning then
     addon:doSkin()
   end
 elseif event == "CHAT_MSG_LOOT" then
   local message = (...) or ""
   local link = message:match(itemstr)
   local id = link and tonumber(link:match("\124Hitem:(%d+):"))
   if id and cageitems[id] then
     addon:doSkin()
   end
 end
end

local frame = CreateFrame("Button", addonName.."HiddenFrame", UIParent)
frame:SetScript("OnEvent", frame_OnEvent)
frame:RegisterEvent("ADDON_LOADED")
frame:RegisterEvent("UNIT_SPELLCAST_START")
frame:RegisterEvent("CHAT_MSG_LOOT")

hash_SlashCmdList["/skinsound"] = nil
SLASH_SKINSOUND1 = "/skinsound"
SlashCmdList["SKINSOUND"] = function(msg)
	local cmd = msg:lower()
	if cmd == "on" then
	  settings.enabled = true
	  chatMsg("Enabled.")
	elseif cmd == "off" then
	  settings.enabled = false
	  chatMsg("Disabled.")
	elseif cmd == "yell" or cmd == "sound" then
	  settings[cmd] = not settings[cmd]
	  chatMsg(cmd.." "..(settings[cmd] and "enabled." or "disabled."))
	else
	  chatMsg("Usage: "..SLASH_SKINSOUND1.." [ on | off | yell | sound ]")
	end
end

